You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@lucene.apache.org by rm...@apache.org on 2015/02/09 20:02:34 UTC

svn commit: r1658539 [3/3] - in /lucene/dev/trunk/solr: ./ contrib/dataimporthandler-extras/src/java/org/apache/solr/handler/dataimport/ contrib/dataimporthandler/src/java/org/apache/solr/handler/dataimport/ contrib/dataimporthandler/src/java/org/apach...

Modified: lucene/dev/trunk/solr/core/src/test/org/apache/solr/cloud/DistribCursorPagingTest.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/test/org/apache/solr/cloud/DistribCursorPagingTest.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/test/org/apache/solr/schema/IndexSchemaTest.java (original)
+++ lucene/dev/trunk/solr/core/src/test/org/apache/solr/schema/IndexSchemaTest.java Mon Feb  9 19:02:32 2015
@@ -38,8 +38,8 @@ public class IndexSchemaTest extends Sol
 
   /**
    * This test assumes the schema includes:
-   * <dynamicField name="dynamic_*" type="string" indexed="true" stored="true"/>
-   * <dynamicField name="*_dynamic" type="string" indexed="true" stored="true"/>
+   * &lt;dynamicField name="dynamic_*" type="string" indexed="true" stored="true"/&gt;
+   * &lt;dynamicField name="*_dynamic" type="string" indexed="true" stored="true"/&gt;
    */
   @Test
   public void testDynamicCopy()

Modified: lucene/dev/trunk/solr/core/src/test/org/apache/solr/search/TestDocSet.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/test/org/apache/solr/search/TestDocSet.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/test/org/apache/solr/search/TestDocSet.java (original)
+++ lucene/dev/trunk/solr/core/src/test/org/apache/solr/search/TestDocSet.java Mon Feb  9 19:02:32 2015
@@ -234,7 +234,7 @@ public class TestDocSet extends LuceneTe
     return sets;
   }
 
-  /**** needs code insertion into HashDocSet
+  /* needs code insertion into HashDocSet
   public void testCollisions() {
     loadfactor=.75f;
     rand=new Random(12345);  // make deterministic
@@ -266,7 +266,7 @@ public class TestDocSet extends LuceneTe
   public static int smallSetType = 0;  // 0==sortedint, 1==hash, 2==FixedBitSet
   public static int smallSetCuttoff=3000;
 
-  /***
+  /*
   public void testIntersectionSizePerformance() {
     loadfactor=.75f; // for HashDocSet    
     rand=new Random(1);  // make deterministic
@@ -299,7 +299,7 @@ public class TestDocSet extends LuceneTe
   }
    ***/
 
-  /****
+  /*
   public void testExistsPerformance() {
     loadfactor=.75f;
     rand=new Random(12345);  // make deterministic
@@ -323,7 +323,7 @@ public class TestDocSet extends LuceneTe
   }
    ***/
 
-   /**** needs code insertion into HashDocSet
+   /* needs code insertion into HashDocSet
    public void testExistsCollisions() {
     loadfactor=.75f;
     rand=new Random(12345);  // make deterministic
@@ -499,7 +499,7 @@ public class TestDocSet extends LuceneTe
     Filter fa = a.getTopFilter();
     Filter fb = b.getTopFilter();
 
-    /*** top level filters are no longer supported
+    /* top level filters are no longer supported
     // test top-level
     DocIdSet da = fa.getDocIdSet(topLevelContext);
     DocIdSet db = fb.getDocIdSet(topLevelContext);

Modified: lucene/dev/trunk/solr/core/src/test/org/apache/solr/search/function/TestOrdValues.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/test/org/apache/solr/search/function/TestOrdValues.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/test/org/apache/solr/search/function/TestOrdValues.java (original)
+++ lucene/dev/trunk/solr/core/src/test/org/apache/solr/search/function/TestOrdValues.java Mon Feb  9 19:02:32 2015
@@ -51,13 +51,13 @@ import org.junit.Test;
 
 /**
  * Test search based on OrdFieldSource and ReverseOrdFieldSource.
- * <p/>
+ * <p>
  * Tests here create an index with a few documents, each having
  * an indexed "id" field.
  * The ord values of this field are later used for scoring.
- * <p/>
+ * <p>
  * The order tests use Hits to verify that docs are ordered as expected.
- * <p/>
+ * <p>
  * The exact score tests use TopDocs top to verify the exact score.
  */
 public class TestOrdValues extends LuceneTestCase {

Modified: lucene/dev/trunk/solr/core/src/test/org/apache/solr/update/processor/StatelessScriptUpdateProcessorFactoryTest.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/test/org/apache/solr/update/processor/StatelessScriptUpdateProcessorFactoryTest.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/core/src/test/org/apache/solr/update/processor/StatelessScriptUpdateProcessorFactoryTest.java (original)
+++ lucene/dev/trunk/solr/core/src/test/org/apache/solr/update/processor/StatelessScriptUpdateProcessorFactoryTest.java Mon Feb  9 19:02:32 2015
@@ -39,7 +39,7 @@ import java.util.List;
 /**
  * Tests {@link StatelessScriptUpdateProcessorFactory}.
  *
- * TODO: This test, to run from an IDE, requires a working directory of <path-to>/solr/core/src/test-files.  Fix!
+ * TODO: This test, to run from an IDE, requires a working directory of &lt;path-to&gt;/solr/core/src/test-files.  Fix!
  */
 public class StatelessScriptUpdateProcessorFactoryTest extends UpdateProcessorTestBase {
 

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/SolrQuery.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/SolrQuery.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/SolrQuery.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/SolrQuery.java Mon Feb  9 19:02:32 2015
@@ -68,7 +68,7 @@ public class SolrQuery extends Modifiabl
 
   /** enable/disable terms.  
    * 
-   * @param b flag to indicate terms should be enabled. <br /> if b==false, removes all other terms parameters
+   * @param b flag to indicate terms should be enabled. <br> if b==false, removes all other terms parameters
    * @return Current reference (<i>this</i>)
    */
   public SolrQuery setTerms(boolean b) {
@@ -319,7 +319,7 @@ public class SolrQuery extends Modifiabl
    * 
    * @param name Name of the facet field to be removed.
    * 
-   * @return true, if the item was removed. <br />
+   * @return true, if the item was removed. <br>
    *           false, if the facet field was null or did not exist.
    */
   public boolean removeFacetField(String name) {
@@ -332,7 +332,7 @@ public class SolrQuery extends Modifiabl
   
   /** enable/disable faceting.  
    * 
-   * @param b flag to indicate faceting should be enabled. <br /> if b==false, removes all other faceting parameters
+   * @param b flag to indicate faceting should be enabled. <br> if b==false, removes all other faceting parameters
    * @return Current reference (<i>this</i>)
    */
   public SolrQuery setFacet(boolean b) {
@@ -475,7 +475,7 @@ public class SolrQuery extends Modifiabl
   /** remove a field for highlighting
    * 
    * @param f field name to not highlight
-   * @return <i>true</i>, if removed, <br /> <i>false</i>, otherwise
+   * @return <i>true</i>, if removed, <br> <i>false</i>, otherwise
    */
   public boolean removeHighlightField(String f) {
     boolean b = this.remove(HighlightParams.FIELDS, f);

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/impl/CloudSolrClient.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/impl/CloudSolrClient.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/impl/CloudSolrClient.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/impl/CloudSolrClient.java Mon Feb  9 19:02:32 2015
@@ -171,11 +171,11 @@ public class CloudSolrClient extends Sol
    *          that starts with a forward slash. Using a chroot allows multiple
    *          applications to coexist in one ensemble. For full details, see the
    *          Zookeeper documentation. Some examples:
-   *          <p/>
+   *          <p>
    *          "host1:2181"
-   *          <p/>
+   *          <p>
    *          "host1:2181,host2:2181,host3:2181/mysolrchroot"
-   *          <p/>
+   *          <p>
    *          "zoo1.example.com:2181,zoo2.example.com:2181,zoo3.example.com:2181"
    */
   public CloudSolrClient(String zkHost) {
@@ -203,11 +203,11 @@ public class CloudSolrClient extends Sol
    *          that starts with a forward slash. Using a chroot allows multiple
    *          applications to coexist in one ensemble. For full details, see the
    *          Zookeeper documentation. Some examples:
-   *          <p/>
+   *          <p>
    *          "host1:2181"
-   *          <p/>
+   *          <p>
    *          "host1:2181,host2:2181,host3:2181/mysolrchroot"
-   *          <p/>
+   *          <p>
    *          "zoo1.example.com:2181,zoo2.example.com:2181,zoo3.example.com:2181"
    * @param httpClient
    *          the {@link HttpClient} instance to be used for all requests. The

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/impl/HttpSolrClient.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/impl/HttpSolrClient.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/impl/HttpSolrClient.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/impl/HttpSolrClient.java Mon Feb  9 19:02:32 2015
@@ -98,7 +98,7 @@ public class HttpSolrClient extends Solr
   
   /**
    * Default value: null / empty.
-   * <p/>
+   * <p>
    * Parameters that are added to every request regardless. This may be a place
    * to add something like an authentication token.
    */
@@ -106,7 +106,7 @@ public class HttpSolrClient extends Solr
   
   /**
    * Default response parser is BinaryResponseParser
-   * <p/>
+   * <p>
    * This parser represents the default Response Parser chosen to parse the
    * response if the parser were not specified as part of the request.
    * 
@@ -665,7 +665,7 @@ public class HttpSolrClient extends Solr
   }
   
   /**
-   * Allow server->client communication to be compressed. Currently gzip and
+   * Allow server-&gt;client communication to be compressed. Currently gzip and
    * deflate are supported. If the server supports compression the response will
    * be compressed. This method is only allowed if the http client is of type
    * DefatulHttpClient.

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/impl/LBHttpSolrClient.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/impl/LBHttpSolrClient.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/impl/LBHttpSolrClient.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/impl/LBHttpSolrClient.java Mon Feb  9 19:02:32 2015
@@ -51,11 +51,11 @@ import java.util.*;
  * {@link CloudSolrClient}, but this class may be used
  * for updates because the server will forward them to the appropriate leader.
  *
- * <p/>
+ * <p>
  * It offers automatic failover when a server goes down and it detects when the server comes back up.
- * <p/>
+ * <p>
  * Load balancing is done using a simple round-robin on the list of servers.
- * <p/>
+ * <p>
  * If a request to a server fails by an IOException due to a connection timeout or read timeout then the host is taken
  * off the list of live servers and moved to a 'dead server list' and the request is resent to the next live server.
  * This process is continued till it tries all the live servers. If at least one server is alive, the request succeeds,
@@ -68,8 +68,8 @@ import java.util.*;
  * </pre></blockquote>
  * This detects if a dead server comes alive automatically. The check is done in fixed intervals in a dedicated thread.
  * This interval can be set using {@link #setAliveCheckInterval} , the default is set to one minute.
- * <p/>
- * <b>When to use this?</b><br/> This can be used as a software load balancer when you do not wish to setup an external
+ * <p>
+ * <b>When to use this?</b><br> This can be used as a software load balancer when you do not wish to setup an external
  * load balancer. Alternatives to this code are to use
  * a dedicated hardware load balancer or using Apache httpd with mod_proxy_balancer as a load balancer. See <a
  * href="http://en.wikipedia.org/wiki/Load_balancing_(computing)">Load balancing on Wikipedia</a>

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/request/ContentStreamUpdateRequest.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/request/ContentStreamUpdateRequest.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/request/ContentStreamUpdateRequest.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/request/ContentStreamUpdateRequest.java Mon Feb  9 19:02:32 2015
@@ -31,7 +31,7 @@ import java.util.List;
  * Basic functionality to upload a File or {@link org.apache.solr.common.util.ContentStream} to a Solr Cell or some
  * other handler that takes ContentStreams (CSV)
  * <p>
- * See http://wiki.apache.org/solr/ExtractingRequestHandler<br/>
+ * See http://wiki.apache.org/solr/ExtractingRequestHandler<br>
  * See http://wiki.apache.org/solr/UpdateCSV
  * 
  *

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/request/RequestWriter.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/request/RequestWriter.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/request/RequestWriter.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/request/RequestWriter.java Mon Feb  9 19:02:32 2015
@@ -32,7 +32,7 @@ import java.nio.charset.StandardCharsets
 
 /**
  * A RequestWriter is used to write requests to Solr.
- * <p/>
+ * <p>
  * A subclass can override the methods in this class to supply a custom format in which a request can be sent.
  *
  *

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/response/AnalysisResponseBase.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/response/AnalysisResponseBase.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/response/AnalysisResponseBase.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/response/AnalysisResponseBase.java Mon Feb  9 19:02:32 2015
@@ -33,7 +33,7 @@ public class AnalysisResponseBase extend
 
   /**
    * Parses the given named list and builds a list of analysis phases form it. Expects a named list of the form:
-   * <p/>
+   * <br>
    * <pre><code>
    *  &lt;lst name="index"&gt;
    *      &lt;arr name="Tokenizer"&gt;
@@ -78,7 +78,7 @@ public class AnalysisResponseBase extend
 
   /**
    * Parses the given named list and builds a token infoform it. Expects a named list of the form:
-   * <p/>
+   * <br>
    * <pre><code>
    *  &lt;arr name="Tokenizer"&gt;
    *      &lt;str name="text"&gt;the_text&lt;/str&gt;

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/util/ClientUtils.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/util/ClientUtils.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/util/ClientUtils.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/client/solrj/util/ClientUtils.java Mon Feb  9 19:02:32 2015
@@ -184,9 +184,10 @@ public class ClientUtils
   //---------------------------------------------------------------------------------------
 
   /**
-   * See: {@link org.apache.lucene.queryparser.classic queryparser syntax} 
+   * See: <a href="https://www.google.com/?gws_rd=ssl#q=lucene+query+parser+syntax">Lucene query parser syntax</a>
    * for more information on Escaping Special Characters
    */
+  // NOTE: its broken to link to any lucene-queryparser.jar docs, not in classpath!!!!!
   public static String escapeQueryChars(String s) {
     StringBuilder sb = new StringBuilder();
     for (int i = 0; i < s.length(); i++) {

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/SolrDocument.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/SolrDocument.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/SolrDocument.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/SolrDocument.java Mon Feb  9 19:02:32 2015
@@ -214,7 +214,7 @@ public class SolrDocument implements Map
   }
 
   /**
-   * Iterate of String->Object keys
+   * Iterate of String-&gt;Object keys
    */
   @Override
   public Iterator<Entry<String, Object>> iterator() {

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/cloud/DocCollection.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/cloud/DocCollection.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/cloud/DocCollection.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/cloud/DocCollection.java Mon Feb  9 19:02:32 2015
@@ -130,14 +130,14 @@ public class DocCollection extends ZkNod
   }
 
   /**
-   * Get the map of all slices (sliceName->Slice) for this collection.
+   * Get the map of all slices (sliceName-&gt;Slice) for this collection.
    */
   public Map<String, Slice> getSlicesMap() {
     return slices;
   }
 
   /**
-   * Get the map of active slices (sliceName->Slice) for this collection.
+   * Get the map of active slices (sliceName-&gt;Slice) for this collection.
    */
   public Map<String, Slice> getActiveSlicesMap() {
     return activeSlices;

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/cloud/ZkOperation.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/cloud/ZkOperation.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/cloud/ZkOperation.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/cloud/ZkOperation.java Mon Feb  9 19:02:32 2015
@@ -1,4 +1,4 @@
-/**
+/*
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/CommonParams.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/CommonParams.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/CommonParams.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/CommonParams.java Mon Feb  9 19:02:32 2015
@@ -151,7 +151,7 @@ public interface CommonParams {
   public static final String STREAM_CONTENTTYPE = "stream.contentType";
   
   /**
-   * Timeout value in milliseconds.  If not set, or the value is <= 0, there is no timeout.
+   * Timeout value in milliseconds.  If not set, or the value is &gt;= 0, there is no timeout.
    */
   public static final String TIME_ALLOWED = "timeAllowed";
   
@@ -206,7 +206,7 @@ public interface CommonParams {
   public static final String CACHE = "cache";
 
   /** Used as a local param on filter queries in conjunction with cache=false.  Filters are checked in order, from
-   * smallest cost to largest. If cost>=100 and the query implements PostFilter, then that interface will be used to do post query filtering.
+   * smallest cost to largest. If cost&gt;=100 and the query implements PostFilter, then that interface will be used to do post query filtering.
    */
   public static final String COST = "cost";
 

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/CoreAdminParams.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/CoreAdminParams.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/CoreAdminParams.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/CoreAdminParams.java Mon Feb  9 19:02:32 2015
@@ -1,4 +1,3 @@
-/**
 /*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/FacetParams.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/FacetParams.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/FacetParams.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/FacetParams.java Mon Feb  9 19:02:32 2015
@@ -151,7 +151,7 @@ public interface FacetParams {
 
  /**
    * When faceting by enumerating the terms in a field,
-   * only use the filterCache for terms with a df >= to this parameter.
+   * only use the filterCache for terms with a df &gt;= to this parameter.
    */
   public static final String FACET_ENUM_CACHE_MINDF = FACET + ".enum.cache.minDf";
   /**
@@ -311,7 +311,7 @@ public interface FacetParams {
   
   /**
    * An enumeration of the legal values for {@link #FACET_DATE_INCLUDE} and {@link #FACET_RANGE_INCLUDE}
-   * <p>
+   * <br>
    * <ul>
    * <li>lower = all gap based ranges include their lower bound</li>
    * <li>upper = all gap based ranges include their upper bound</li>

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/QueryElevationParams.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/QueryElevationParams.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/QueryElevationParams.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/QueryElevationParams.java Mon Feb  9 19:02:32 2015
@@ -32,7 +32,7 @@ public interface QueryElevationParams {
   /**
    * The name of the field that editorial results will be written out as when using the QueryElevationComponent, which
    * automatically configures the EditorialMarkerFactory.  The default name is "elevated"
-   * <br/>
+   * <br>
    * See http://wiki.apache.org/solr/DocTransformers
    */
   String EDITORIAL_MARKER_FIELD_NAME = "editorialMarkerFieldName";
@@ -40,7 +40,7 @@ public interface QueryElevationParams {
    * The name of the field that excluded editorial results will be written out as when using the QueryElevationComponent, which
    * automatically configures the EditorialMarkerFactory.  The default name is "excluded".  This is only used
    * when {@link #MARK_EXCLUDES} is set to true at query time.
-   * <br/>
+   * <br>
    * See http://wiki.apache.org/solr/DocTransformers
    */
   String EXCLUDE_MARKER_FIELD_NAME = "excludeMarkerFieldName";

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/SpellingParams.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/SpellingParams.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/SpellingParams.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/params/SpellingParams.java Mon Feb  9 19:02:32 2015
@@ -34,7 +34,7 @@ public interface SpellingParams {
 
   /**
    * The count of suggestions to return for each query term not in the index and/or dictionary.
-   * <p/>
+   * <p>
    * If this parameter is absent in the request then only one suggestion is
    * returned. If it is more than one then a maximum of given suggestions are
    * returned for each token in the query.
@@ -43,7 +43,7 @@ public interface SpellingParams {
   
   /**
    * The count of suggestions to return for each query term existing in the index and/or dictionary.
-   * <p/>
+   * <p>
    * If this parameter is absent in the request then no suggestions are generated.  This parameter allows
    * for receiving alternative terms to use in context-sensitive spelling corrections.
    */
@@ -70,7 +70,7 @@ public interface SpellingParams {
    * When this parameter is set to true and the misspelled word exists in the
    * user field, only words that occur more frequently in the Solr field than
    * the one given will be returned. The default value is false.
-   * <p/>
+   * <p>
    * <b>This is applicable only for dictionaries built from Solr fields.</b>
    */
   public static final String SPELLCHECK_ONLY_MORE_POPULAR = SPELLCHECK_PREFIX + "onlyMorePopular";
@@ -79,14 +79,14 @@ public interface SpellingParams {
    * Whether to use the extended response format, which is more complicated but
    * richer. Returns the document frequency for each suggestion and returns one
    * suggestion block for each term in the query string. Default is false.
-   * <p/>
+   * <p>
    * <b>This is applicable only for dictionaries built from Solr fields.</b>
    */
   public static final String SPELLCHECK_EXTENDED_RESULTS = SPELLCHECK_PREFIX + "extendedResults";
 
   /**
    * Use the value for this parameter as the query to spell check.
-   * <p/>
+   * <p>
    * This parameter is <b>optional</b>. If absent, then the q parameter is
    * used.
    */
@@ -148,7 +148,7 @@ public interface SpellingParams {
   /**
    * <p>
    * Whether to use the Extended Results Format for collations. 
-   * Includes "before>after" pairs to easily allow clients to generate messages like "no results for PORK.  did you mean POLK?"
+   * Includes "before&gt;after" pairs to easily allow clients to generate messages like "no results for PORK.  did you mean POLK?"
    * Also indicates the # of hits each collation will return on re-query.  Default=false, which retains 1.4-compatible output.
    * </p>
    * <p>

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/DateUtil.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/DateUtil.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/DateUtil.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/DateUtil.java Mon Feb  9 19:02:32 2015
@@ -105,7 +105,7 @@ public class DateUtil {
 
   /**
    * Slightly modified from org.apache.commons.httpclient.util.DateUtil.parseDate
-   * <p/>
+   * <p>
    * Parses the date value using the given date formats.
    *
    * @param dateValue   the date value to parse

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/FastOutputStream.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/FastOutputStream.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/FastOutputStream.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/FastOutputStream.java Mon Feb  9 19:02:32 2015
@@ -101,7 +101,7 @@ public class FastOutputStream extends Ou
 
 
   /** reserve at least len bytes at the end of the buffer.
-   * Invalid if len > buffer.length
+   * Invalid if len &gt; buffer.length
    */
   public void reserve(int len) throws IOException {
     if (len > (buf.length - pos))

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/Hash.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/Hash.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/Hash.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/Hash.java Mon Feb  9 19:02:32 2015
@@ -178,7 +178,7 @@ public class Hash {
 
 
   /**<p>This is the 64 bit version of lookup3ycs, corresponding to Bob Jenkin's
-   * lookup3 hashlittle2 with initval biased by -(numCodePoints<<2).  It is equivalent
+   * lookup3 hashlittle2 with initval biased by -(numCodePoints&lt;&lt;2).  It is equivalent
    * to lookup3ycs in that if the high bits of initval==0, then the low bits of the
    * result will be the same as lookup3ycs.
    * </p>

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/JavaBinCodec.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/JavaBinCodec.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/JavaBinCodec.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/JavaBinCodec.java Mon Feb  9 19:02:32 2015
@@ -36,7 +36,7 @@ import java.nio.ByteBuffer;
  * object in the object tree which does not fall into these types, It must be converted to one of these. Implement an
  * ObjectResolver and pass it over It is expected that this class is used on both end of the pipes. The class has one
  * read method and one write method for each of the datatypes
- * <p/>
+ * <p>
  * Note -- Never re-use an instance of this class for more than one marshal or unmarshall operation. Always create a new
  * instance.
  */
@@ -732,7 +732,7 @@ public class JavaBinCodec {
 
   /**
    * Special method for variable length int (copied from lucene). Usually used for writing the length of a
-   * collection/array/map In most of the cases the length can be represented in one byte (length < 127) so it saves 3
+   * collection/array/map In most of the cases the length can be represented in one byte (length &lt; 127) so it saves 3
    * bytes/object
    *
    * @throws IOException If there is a low-level I/O error.

Modified: lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/StrUtils.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/StrUtils.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/StrUtils.java (original)
+++ lucene/dev/trunk/solr/solrj/src/java/org/apache/solr/common/util/StrUtils.java Mon Feb  9 19:02:32 2015
@@ -78,7 +78,7 @@ public class StrUtils {
    * <p>
    * Current backslash escaping supported:
    * <br> \n \t \r \b \f are escaped the same as a Java String
-   * <br> Other characters following a backslash are produced verbatim (\c => c)
+   * <br> Other characters following a backslash are produced verbatim (\c =&gt; c)
    *
    * @param s  the string to split
    * @param separator the separator to split on
@@ -258,7 +258,6 @@ public class StrUtils {
    * <p>
    * Characters with a numeric value less than 32 are encoded.
    * &amp;,=,%,+,space are encoded.
-   * <p>
    */
   public static void partialURLEncodeVal(Appendable dest, String val) throws IOException {
     for (int i=0; i<val.length(); i++) {

Modified: lucene/dev/trunk/solr/test-framework/src/java/org/apache/solr/BaseDistributedSearchTestCase.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/test-framework/src/java/org/apache/solr/BaseDistributedSearchTestCase.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================
--- lucene/dev/trunk/solr/test-framework/src/java/org/apache/solr/BaseDistributedSearchTestCase.java (original)
+++ lucene/dev/trunk/solr/test-framework/src/java/org/apache/solr/BaseDistributedSearchTestCase.java Mon Feb  9 19:02:32 2015
@@ -1000,7 +1000,7 @@ public abstract class BaseDistributedSea
   /**
    * Implementations can pre-test the control data for basic correctness before using it
    * as a check for the shard data.  This is useful, for instance, if a test bug is introduced
-   * causing a spelling index not to get built:  both control & shard data would have no results
+   * causing a spelling index not to get built:  both control &amp; shard data would have no results
    * but because they match the test would pass.  This method gives us a chance to ensure something
    * exists in the control data.
    */
--- lucene/dev/trunk/solr/core/src/test/org/apache/solr/cloud/DistribCursorPagingTest.java (original)
+++ lucene/dev/trunk/solr/core/src/test/org/apache/solr/cloud/DistribCursorPagingTest.java Mon Feb  9 19:02:32 2015
@@ -17,6 +17,7 @@
 package org.apache.solr.cloud;
 
 import com.carrotsearch.randomizedtesting.annotations.Seed;
+
 import org.apache.lucene.util.LuceneTestCase.Slow;
 import org.apache.lucene.util.SentinelIntSet;
 import org.apache.lucene.util.TestUtil;
@@ -30,15 +31,17 @@ import org.apache.solr.common.SolrExcept
 import org.apache.solr.common.SolrException.ErrorCode;
 import org.apache.solr.common.SolrInputDocument;
 import org.apache.solr.common.params.CommonParams;
+import org.apache.solr.common.params.CursorMarkParams;
 import org.apache.solr.common.params.GroupParams;
 import org.apache.solr.common.params.SolrParams;
 import org.apache.solr.common.util.NamedList;
 import org.apache.solr.search.CursorMark;
+
 import static org.apache.solr.common.params.CursorMarkParams.CURSOR_MARK_PARAM;
 import static org.apache.solr.common.params.CursorMarkParams.CURSOR_MARK_NEXT;
 import static org.apache.solr.common.params.CursorMarkParams.CURSOR_MARK_START;
-import org.apache.solr.search.CursorMark; //jdoc
 
+import org.apache.solr.search.CursorMark; //jdoc
 import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -50,7 +53,7 @@ import java.util.List;
 import java.util.Map;
 
 /**
  * Distributed tests of deep paging using {@link CursorMark} and {@link #CURSOR_MARK_PARAM}.
  * 
  * NOTE: this class Reuses some utilities from {@link CursorPagingTest} that assume the same schema and configs.
  *
@@ -669,7 +672,7 @@ public class DistribCursorPagingTest ext
 
   /**
    * Given a QueryResponse returned by SolrServer.query, asserts that the
    * response does include {@link #CURSOR_MARK_NEXT} key and returns it
    * @see org.apache.solr.client.solrj.SolrClient#query
    */
   private String assertHashNextCursorMark(QueryResponse rsp) {
@@ -686,8 +689,8 @@ public class DistribCursorPagingTest ext
 
   /**
    * <p>
    * Given a set of params, executes a cursor query using {@link #CURSOR_MARK_START} 
    * and then continuously walks the results using {@link #CURSOR_MARK_START} as long 
    * as a non-0 number of docs ar returned.  This method records the the set of all id's
    * (must be postive ints) encountered and throws an assertion failure if any id is 
    * encountered more then once, or if the set grows above maxSize
@@ -50,7 +53,7 @@ import java.util.List;
 
 /**
- * Distributed tests of deep paging using {@link CursorMark} and {@link #CURSOR_MARK_PARAM}.
+ * Distributed tests of deep paging using {@link CursorMark} and {@link CursorMarkParams#CURSOR_MARK_PARAM}.
  * 
  * NOTE: this class Reuses some utilities from {@link CursorPagingTest} that assume the same schema and configs.
@@ -669,7 +672,7 @@ public class DistribCursorPagingTest ext
   /**
    * Given a QueryResponse returned by SolrServer.query, asserts that the
-   * response does include {@link #CURSOR_MARK_NEXT} key and returns it
+   * response does include {@link CursorMarkParams#CURSOR_MARK_NEXT} key and returns it
    * @see org.apache.solr.client.solrj.SolrClient#query
    */
@@ -686,8 +689,8 @@ public class DistribCursorPagingTest ext
   /**
    * <p>
-   * Given a set of params, executes a cursor query using {@link #CURSOR_MARK_START} 
-   * and then continuously walks the results using {@link #CURSOR_MARK_START} as long 
+   * Given a set of params, executes a cursor query using {@link CursorMarkParams#CURSOR_MARK_START} 
+   * and then continuously walks the results using {@link CursorMarkParams#CURSOR_MARK_START} as long 
    * as a non-0 number of docs ar returned.  This method records the the set of all id's
    * (must be postive ints) encountered and throws an assertion failure if any id is 

Modified: lucene/dev/trunk/solr/core/src/test/org/apache/solr/schema/IndexSchemaTest.java
URL: http://svn.apache.org/viewvc/lucene/dev/trunk/solr/core/src/test/org/apache/solr/schema/IndexSchemaTest.java?rev=1658539&r1=1658538&r2=1658539&view=diff
==============================================================================